@@ -15,14 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-download.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-download.c 7858 2008-01-13 20:42:01Z cosimoc $
  */
 
 #include "config.h"
 
 #include "ephy-download.h"
 
-#include <libgnomevfs/gnome-vfs-uri.h>
+#include <glib/gi18n.h>
 
 #define EPHY_DOWNLOAD_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_DOWNLOAD, EphyDownloadPrivate))
 
@@ -115,21 +115,18 @@ ephy_download_new (void)
 char *
 ephy_download_get_name (EphyDownload *download)
 {
-	GnomeVFSURI *uri;
 	char *target;
 	char *result;
 
 	target = ephy_download_get_target (download);
 
-	uri = gnome_vfs_uri_new (target);
-	if (uri)
+	if (target)
 	{
-		result = gnome_vfs_uri_extract_short_name (uri);
-		gnome_vfs_uri_unref (uri);
+		result = g_path_get_basename (target);
 	}
 	else
 	{
-		result = g_strdup ("Unknown");
+		result = g_strdup (_("Unknown"));
 	}
 
 	g_free (target);
