@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-password-manager.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-password-manager.c 7623 2007-11-04 23:35:28Z cosimoc $
  */
 
 #include "config.h"
@@ -186,6 +186,19 @@ ephy_password_manager_remove_password (EphyPasswordManager *manager,
 	iface->remove (manager, info);
 }
 
+/**
+ * ephy_password_manager_remove_all_passwords:
+ * @manager: the #EphyPasswordManager
+ *
+ * Removes all the password entries from the password database.
+ **/
+void
+ephy_password_manager_remove_all_passwords (EphyPasswordManager *manager)
+{
+	EphyPasswordManagerIface *iface = EPHY_PASSWORD_MANAGER_GET_IFACE (manager);
+	iface->remove_all (manager);
+}
+
 /**
  * ephy_password_manager_list_passwords:
  * @manager: the #EphyPasswordManager
