@@ -1,5 +1,5 @@
 /* 
- *  Copyright (C) 2006 Christian Persch
+ *  Copyright © 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -9,21 +9,21 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: AutoJSContextStack.cpp,v 1.1.2.2 2006/02/05 19:12:33 chpe Exp $
+ *  $Id: AutoJSContextStack.cpp 7426 2007-09-13 13:18:57Z chpe $
  */
 
 #include "mozilla-config.h"
 #include "config.h"
 
-#include "AutoJSContextStack.h"
+#include <nsServiceManagerUtils.h>
 
-#include <nsIServiceManager.h>
+#include "AutoJSContextStack.h"
 
 AutoJSContextStack::~AutoJSContextStack()
 {
