@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp 7300 2007-08-26 21:49:58Z diegoe $
+ * $Id: MozDownload.cpp 7858 2008-01-13 20:42:01Z cosimoc $
  */
 
 #include "mozilla-config.h"
@@ -47,6 +47,8 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
+#include <gio/gdesktopappinfo.h>
+#include <gio/gio.h>
 
 #include <nsStringAPI.h>
 
@@ -69,7 +71,10 @@
 #include <nsNetError.h>
 #include <nsServiceManagerUtils.h>
 
+#ifndef HAVE_GECKO_1_9
 #include "EphyBadCertRejector.h"
+#endif
+
 #include "EphyUtils.h"
 
 #include "eel-gconf-extensions.h"
@@ -348,7 +353,7 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 #ifdef HAVE_GECKO_1_9
 			return NS_OK;
 #else
-			GnomeVFSMimeApplication *helperApp;
+			GDesktopAppInfo *helperApp;
 			NS_ENSURE_TRUE (mMIMEInfo, NS_ERROR_FAILURE);
 
 			nsString description;
@@ -368,16 +373,22 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 				char *end;
 				guint32 user_time = strtoul (str[1], &end, 0);
 
-				helperApp = gnome_vfs_mime_application_new_from_desktop_id (str[2]);
+				helperApp = g_desktop_app_info_new (str[2]);
 				if (!helperApp) return NS_ERROR_FAILURE;
 
 				nsCString aDest;
 				rv = mDestination->GetSpec (aDest);
 				NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+                
+                GFile* file;
+                GList* list = NULL;
 
-				ephy_file_launch_application (helperApp, destSpec.get (), user_time);
+                file = g_file_new_for_uri (destSpec.get ());
+                list = g_list_append (list, file);
+				ephy_file_launch_application (G_APP_INFO (helperApp), list, user_time, NULL);
 
-				gnome_vfs_mime_application_free (helperApp);
+                g_list_free (list);
+                g_object_unref (file);
 				g_strfreev (str);
 			}
 			else if (g_str_has_prefix (cDesc.get(), "gnome-browse-to-file:"))
@@ -505,6 +516,7 @@ MozDownload::OnSecurityChange (nsIWebProgress *aWebProgress, nsIRequest *aReques
 NS_IMETHODIMP
 MozDownload::GetInterface(const nsIID & uuid, void * *result)
 {
+#ifndef HAVE_GECKO_1_9
 	if (uuid.Equals (NS_GET_IID (nsIBadCertListener)) &&
 	    mEmbedPersist)
 	{
@@ -523,7 +535,7 @@ MozDownload::GetInterface(const nsIID & uuid, void * *result)
 			return NS_OK;
 		}
 	}
-
+#endif
 	return NS_ERROR_NO_INTERFACE;
 }
 
