@@ -39,15 +39,14 @@
 #include "EphyUtils.h"
 #include "EventContext.h"
 
-#include "ephy-base-embed.h"
 #include "ephy-command-manager.h"
 #include "ephy-debug.h"
+#include "mozilla-embed.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
 #include "mozilla-embed-event.h"
-
-#include "mozilla-embed.h"
+#include "mozilla-history-item.h"
 
 static void	mozilla_embed_class_init	(MozillaEmbedClass *klass);
 static void	mozilla_embed_init		(MozillaEmbed *gs);
@@ -670,43 +669,6 @@ impl_shistory_n_items (EphyEmbed *embed)
 	return NS_SUCCEEDED(rv) ? count : 0;
 }
 
-static void
-impl_shistory_get_nth (EphyEmbed *embed, 
-		       int nth,
-		       gboolean is_relative,
-		       char **aUrl,
-		       char **aTitle)
-{
-	nsresult rv;
-	nsCString url;
-	PRUnichar *title;
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
-
-	if (is_relative)
-	{
-		nth += ephy_embed_shistory_get_pos (embed);
-	}
-	
-	rv = mpriv->browser->GetSHUrlAtIndex(nth, url);
-
-	*aUrl = (NS_SUCCEEDED (rv) && url.Length()) ? g_strdup(url.get()) : NULL;
-
-	rv = mpriv->browser->GetSHTitleAtIndex(nth, &title);
-
-	if (title)
-	{
-		nsCString cTitle;
-		NS_UTF16ToCString (nsString(title),
-				   NS_CSTRING_ENCODING_UTF8, cTitle);
-		*aTitle = g_strdup (cTitle.get());
-		nsMemory::Free (title);
-	}
-	else
-	{
-		*aTitle = NULL;
-	}
-}
-
 static int
 impl_shistory_get_pos (EphyEmbed *embed)
 {
@@ -719,15 +681,6 @@ impl_shistory_get_pos (EphyEmbed *embed)
 	return NS_SUCCEEDED(rv) ? index : 0;
 }
 
-static void
-impl_shistory_go_nth (EphyEmbed *embed, 
-		      int nth)
-{
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
-
-	mpriv->browser->GoToHistoryIndex (nth);
-}
-
 static void
 impl_shistory_copy (EphyEmbed *source,
 		    EphyEmbed *dest,
@@ -878,6 +831,89 @@ impl_has_modified_forms (EphyEmbed *embed)
 	return NS_SUCCEEDED (rv) ? modified : FALSE;
 }
 
+static EphyHistoryItem*
+mozilla_get_nth_history_item (MozillaEmbed *embed,
+			      gboolean is_relative,
+			      int nth)
+{
+	EphyHistoryItem *item = NULL;
+
+	if (is_relative)
+	{
+		nth += impl_shistory_get_pos (EPHY_EMBED (embed));
+	}
+	
+	if (nth >= 0 && nth <= impl_shistory_n_items (EPHY_EMBED (embed)))
+	{
+		item = (EphyHistoryItem*)mozilla_history_item_new (embed, nth);
+	}
+
+	return item;
+}
+
+static GList*
+mozilla_construct_history_list (MozillaEmbed *embed, int start, int end)
+{
+	GList *list = NULL;
+	EphyHistoryItem *item;
+
+	while (start != end)
+	{
+		item = mozilla_get_nth_history_item (embed, FALSE, start);
+		list = g_list_prepend (list, item);
+
+		if (start < end)
+			start++;
+		else
+			start--;
+	}
+
+	return g_list_reverse (list);
+}
+
+static GList*
+impl_get_backward_history (EphyEmbed *embed)
+{
+	MozillaEmbed *membed = MOZILLA_EMBED (embed);
+	int start = impl_shistory_get_pos (embed) + -1;
+
+	return mozilla_construct_history_list (membed, start, -1);
+}
+
+static GList*
+impl_get_forward_history (EphyEmbed *embed)
+{
+	MozillaEmbed *membed = MOZILLA_EMBED (embed);
+	int start = impl_shistory_get_pos (embed) + 1;
+	int end = impl_shistory_n_items (embed);
+
+	return mozilla_construct_history_list (membed, start, end);
+}
+
+static EphyHistoryItem*
+impl_get_next_history_item (EphyEmbed *embed)
+{
+	return mozilla_get_nth_history_item (MOZILLA_EMBED (embed),
+					     TRUE,
+					     +1);
+}
+
+static EphyHistoryItem*
+impl_get_previous_history_item (EphyEmbed *embed)
+{
+	return mozilla_get_nth_history_item (MOZILLA_EMBED (embed),
+					     TRUE,
+					     -1);
+}
+
+static void
+impl_go_to_history_item (EphyEmbed *embed, EphyHistoryItem *item)
+{
+	MozillaHistoryItem *mitem = MOZILLA_HISTORY_ITEM (item);
+
+	MOZILLA_EMBED (embed)->priv->browser->GoToHistoryIndex (mitem->nth);
+}
+
 static void
 mozilla_embed_location_changed_cb (GtkMozEmbed *embed, 
 				   MozillaEmbed *membed)
@@ -1373,10 +1409,6 @@ ephy_embed_iface_init (EphyEmbedIface *iface)
 	iface->scroll_lines = impl_scroll_lines;
 	iface->scroll_pages = impl_scroll_pages;
 	iface->scroll_pixels = impl_scroll_pixels;
-	iface->shistory_n_items = impl_shistory_n_items;
-	iface->shistory_get_nth = impl_shistory_get_nth;
-	iface->shistory_get_pos = impl_shistory_get_pos;
-	iface->shistory_go_nth = impl_shistory_go_nth;
 	iface->shistory_copy = impl_shistory_copy;
 	iface->show_page_certificate = impl_show_page_certificate;
 	iface->close = impl_close;
@@ -1389,6 +1421,11 @@ ephy_embed_iface_init (EphyEmbedIface *iface)
 	iface->print_preview_navigate = impl_print_preview_navigate;
 	iface->has_modified_forms = impl_has_modified_forms;
 	iface->get_security_level = impl_get_security_level;
+	iface->get_backward_history = impl_get_backward_history;
+	iface->get_forward_history = impl_get_forward_history;
+	iface->get_next_history_item = impl_get_next_history_item;
+	iface->get_previous_history_item = impl_get_previous_history_item;
+	iface->go_to_history_item = impl_go_to_history_item;
 }
 
 static void
@@ -1469,3 +1506,11 @@ _mozilla_embed_new_xul_dialog (void)
 
 	return GTK_MOZ_EMBED (embed);
 }
+
+EphyBrowser*
+_mozilla_embed_get_browser (MozillaEmbed *embed)
+{
+	g_return_val_if_fail (MOZILLA_IS_EMBED (embed), NULL);
+
+	return embed->priv->browser;
+}
