@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmark-action.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-bookmark-action.c 7858 2008-01-13 20:42:01Z cosimoc $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 #include "ephy-dnd.h"
+#include "ephy-string.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtkwidget.h>
@@ -46,7 +47,6 @@
 #include <gtk/gtkentry.h>
 #include <gtk/gtktoolitem.h>
 #include <gtk/gtkmain.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
 
 #include <string.h>
 
@@ -80,6 +80,73 @@ enum
 
 static GObjectClass *parent_class;
 
+typedef struct
+{
+	GObject *weak_ptr;
+	GtkWidget *entry;
+	EphyLinkFlags flags;
+} ClipboardCtx;
+
+static void
+clipboard_text_received_cb (GtkClipboard *clipboard,
+			    const char *text,
+			    ClipboardCtx *ctx)
+{
+	if (ctx->weak_ptr != NULL && text != NULL)
+	{
+		/* This is to avoid middle-clicking on a non-empty smart bookmark
+		 * triggering another search.
+		 */
+		if (strcmp (text, gtk_entry_get_text (GTK_ENTRY (ctx->entry))) != 0)
+		{
+			gtk_entry_set_text (GTK_ENTRY (ctx->entry), text);
+			ephy_bookmark_action_activate (EPHY_BOOKMARK_ACTION (ctx->weak_ptr),
+						       ctx->entry, ctx->flags);
+		}
+	}
+
+	if (ctx->weak_ptr != NULL)
+	{
+		GObject **object = &(ctx->weak_ptr);
+		g_object_remove_weak_pointer (G_OBJECT (ctx->weak_ptr), 
+					      (gpointer *)object);
+	}
+
+	g_slice_free (ClipboardCtx, ctx);
+}
+
+static gboolean
+entry_button_press_event_cb (GtkWidget *entry,
+			     GdkEventButton *event,
+			     GtkAction *action)
+{
+	if (event->button == 2) /* middle click */
+	{
+		ClipboardCtx *ctx;
+		GObject **object;
+
+		ctx = g_slice_new (ClipboardCtx);
+		ctx->flags = EPHY_LINK_NEW_TAB | EPHY_LINK_JUMP_TO;
+		ctx->entry = entry;
+
+		/* We need to make sure we know if the action is destroyed between
+		 * requesting the clipboard contents, and receiving them.
+	 	 */
+
+		ctx->weak_ptr = G_OBJECT (action);
+		object = &(ctx->weak_ptr);
+		g_object_add_weak_pointer (ctx->weak_ptr, (gpointer *)object);
+
+		gtk_clipboard_request_text
+			(gtk_widget_get_clipboard (entry, GDK_SELECTION_PRIMARY),
+			 (GtkClipboardTextReceivedFunc) clipboard_text_received_cb,
+			 ctx);
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static GtkWidget *
 create_tool_item (GtkAction *action)
 {
@@ -105,6 +172,8 @@ create_tool_item (GtkAction *action)
 	gtk_entry_set_width_chars (GTK_ENTRY (entry), ENTRY_WIDTH_CHARS);
 	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
 	g_object_set_data (G_OBJECT (item), "entry", entry);
+	g_signal_connect (entry, "button-press-event",
+			  G_CALLBACK (entry_button_press_event_cb), action);
 
 	hbox = gtk_hbox_new (FALSE, 3);
 	gtk_widget_show (hbox);
@@ -298,16 +367,17 @@ ephy_bookmark_action_activate (EphyBookmarkAction *action,
 	/* The entered search term is empty, and we have a smart bookmark */
 	if ((text == NULL || text[0] == '\0') && strstr (location, "%s") != NULL)
 	{
-		GnomeVFSURI *uri = gnome_vfs_uri_new (location);
-		if (uri != NULL)
-		{
-			address = g_strconcat (
-					gnome_vfs_uri_get_scheme (uri),
-					"://",
-					gnome_vfs_uri_get_host_name (uri),
-					NULL);
-			gnome_vfs_uri_unref (uri);
-		}
+		char *scheme;
+		char *host_name;
+
+		scheme = g_uri_get_scheme (location);
+		host_name = ephy_string_get_host_name (location);
+		address = g_strconcat (scheme,
+				       "://",
+				       host_name,
+				       NULL);
+		g_free (scheme);
+		g_free (host_name);
 	}
 
 	if (address == NULL)
@@ -417,49 +487,72 @@ toolbar_reconfigured_cb (GtkToolItem *toolitem,
 
 
 static gboolean
-set_tooltip_cb (GtkToolItem *toolitem,
-		GtkTooltips *tooltips,
-		gchar *tip_text,
-		gchar *tip_private,
-		GtkAction *action)
+query_tooltip_cb (GtkWidget *proxy,
+		  gint x,
+    		  gint y,
+		  gboolean keyboard_mode,
+		  GtkTooltip *tooltip,
+		  GtkAction *action)
 {
 	EphyBookmarks *bookmarks;
 	EphyNode *node;
-	GtkWidget *button;
-	
 	const char *title, *location;
-	char *tooltip;
+	char *text = NULL;
 	
 	node = ephy_bookmark_action_get_bookmark (EPHY_BOOKMARK_ACTION (action));
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
 	title = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_TITLE);
 	location = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_LOCATION);
-	tooltip = NULL;
 	
-	if (strstr (location, "%s") != NULL)
+	if (g_str_has_prefix (location, "javascript:"))
 	{
-		GnomeVFSURI *uri = gnome_vfs_uri_new (location);
-		if (uri != NULL)
+		text = g_strdup_printf (_("Executes the script “%s”"), title);
+	}
+	else
+	{
+		if (strstr (location, "%s") != NULL)
 		{
-			tooltip = g_strconcat
-			  (title, "\n", gnome_vfs_uri_get_scheme (uri),
-			   "://", gnome_vfs_uri_get_host_name (uri), NULL);
-			gnome_vfs_uri_unref (uri);
+			char *scheme;
+			char *host_name;
+			
+			scheme = g_uri_get_scheme (location);
+			host_name = ephy_string_get_host_name (location);
+		
+			if (title[0] == '\0')
+			{
+				text = g_markup_printf_escaped ("%s://%s",
+								scheme,
+								host_name);
+			}
+			else
+			{
+				text = g_markup_printf_escaped ("%s\n%s://%s",
+								title,
+								scheme,
+								host_name);
+			}
+			
+			g_free (scheme);
+			g_free (host_name);
+		}
+		if (text == NULL)
+		{
+			if (title[0] == '\0')
+			{
+				text = g_markup_printf_escaped ("%s", location);
+			}
+			else
+			{
+				text = g_markup_printf_escaped ("%s\n%s", title, location);
+			}
 		}
 	}
-	if (tooltip == NULL)
-	{
-		tooltip = g_strconcat (title, "\n", location, NULL);
-	}
-	
-	button = g_object_get_data (G_OBJECT (toolitem), "button");
-	gtk_tooltips_set_tip (tooltips, button, tooltip, NULL);
-	g_free (tooltip);
+	gtk_tooltip_set_markup (tooltip, text);
+	g_free (text);
 	
 	return TRUE;
 }
 
-
 static void
 connect_proxy (GtkAction *action,
 	       GtkWidget *proxy)
@@ -486,8 +579,11 @@ connect_proxy (GtkAction *action,
 		
 		g_signal_connect (proxy, "toolbar-reconfigured",
 				  G_CALLBACK (toolbar_reconfigured_cb), action);
-		g_signal_connect (proxy, "set-tooltip", 
-				  G_CALLBACK (set_tooltip_cb), action);
+
+		/* FIXME: maybe make the tooltip cover only the button, not also the entry (if there is one?) */
+		gtk_widget_set_has_tooltip (proxy, TRUE);
+		g_signal_connect (proxy, "query-tooltip",
+				  G_CALLBACK (query_tooltip_cb), action);
 
 		button = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "button"));
 		g_signal_connect (button, "clicked", G_CALLBACK (activate_cb), action);
@@ -546,10 +642,14 @@ ephy_bookmark_action_updated (EphyBookmarkAction *action)
 	
 	/* Notify all other properties */
 	g_object_notify (G_OBJECT (action), "location");
-	g_object_notify (G_OBJECT (action), "tooltip");
 	g_object_notify (G_OBJECT (action), "icon");
 	
-	g_object_thaw_notify (G_OBJECT (action));        
+	g_object_thaw_notify (G_OBJECT (action));
+
+	/* We could force a tooltip re-query with gtk_tooltip_trigger_tooltip_query
+	 * here, but it's not really worth it. Just show the updated tip next time
+	 * the tip is queried.
+	 */
 }
 
 EphyNode *
@@ -678,40 +778,30 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 
 	g_object_class_install_property (object_class,
 					 PROP_BOOKMARK,
-					 g_param_spec_pointer ("bookmark",
-							       "bookmark",
-							       "bookmark",
+					 g_param_spec_pointer ("bookmark", NULL, NULL,
 							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							       G_PARAM_CONSTRUCT_ONLY));
 
 	/* overwrite GtkActionClass::tooltip, so we can use the url as tooltip */
 	g_object_class_install_property (object_class,
 					 PROP_TOOLTIP,
-					 g_param_spec_string  ("tooltip",
-							       "tooltip",
-							       "tooltip",
+					 g_param_spec_string  ("tooltip", NULL, NULL,
 							       NULL,
 							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	
 	g_object_class_install_property (object_class,
 					 PROP_LOCATION,
-					 g_param_spec_string  ("location",
-							       "location",
-							       "location",
+					 g_param_spec_string  ("location", NULL, NULL,
 							       NULL,
 							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	g_object_class_install_property (object_class,
 					 PROP_SMART_URL,
-					 g_param_spec_boolean  ("smarturl",
-								"smarturl",
-								"smarturl",
+					 g_param_spec_boolean  ("smarturl", NULL, NULL,
 								FALSE,
 								G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	g_object_class_install_property (object_class,
 					 PROP_ICON,
-					 g_param_spec_string  ("icon",
-							       "icon",
-							       "icon",
+					 g_param_spec_string  ("icon", NULL, NULL,
 							       NULL,
 							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
