@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-net-monitor.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-net-monitor.c 7535 2007-10-18 19:15:05Z cosimoc $
  */
 
 #include "config.h"
@@ -151,19 +151,9 @@ filter_func (DBusConnection *connection,
 
 	if (dbus_message_is_signal (message,
 				    NM_DBUS_INTERFACE,
-				    "DeviceNoLongerActive"))
+				    "StateChange"))
 	{
-		LOG ("EphyNetMonitor catches DeviceNoLongerActive signal");
-
-		ephy_net_monitor_check_network (monitor);
-
-		return DBUS_HANDLER_RESULT_HANDLED;
-	}
-	if (dbus_message_is_signal (message,
-				    NM_DBUS_INTERFACE,
-				    "DeviceNowActive"))
-	{
-		LOG ("EphyNetMonitor catches DeviceNowActive signal");
+		LOG ("EphyNetMonitor catches StateChange signal");
 
 		ephy_net_monitor_check_network (monitor);
 
