@@ -16,13 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: popup-commands.c 7167 2007-07-16 15:30:51Z chpe $
+ *  $Id: popup-commands.c 7858 2008-01-13 20:42:01Z cosimoc $
  */
 
 #include "config.h"
 
 #include "popup-commands.h"
 #include "ephy-shell.h"
+#include "ephy-embed-container.h"
 #include "ephy-embed-factory.h"
 #include "ephy-embed-persist.h"
 #include "ephy-prefs.h"
@@ -34,27 +35,24 @@
 #include <glib/gi18n.h>
 #include <gtk/gtkclipboard.h>
 #include <gtk/gtkmain.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-file-info.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 void
 popup_cmd_link_in_new_window (GtkAction *action,
 		              EphyWindow *window)
 {
 	EphyEmbedEvent *event;
-	EphyTab *tab;
+	EphyEmbed *embed;
 	const GValue *value;
 
-	tab = ephy_window_get_active_tab (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
 	value = ephy_embed_event_get_property (event, "link");
 
-	ephy_shell_new_tab (ephy_shell, NULL, tab,
+	ephy_shell_new_tab (ephy_shell, NULL, embed,
 			    g_value_get_string (value),
 			    EPHY_NEW_TAB_OPEN_PAGE |
 			    EPHY_NEW_TAB_IN_NEW_WINDOW);
@@ -65,17 +63,18 @@ popup_cmd_link_in_new_tab (GtkAction *action,
 		           EphyWindow *window)
 {
 	EphyEmbedEvent *event;
-	EphyTab *tab;
+	EphyEmbed *embed;
 	const GValue *value;
 
-	tab = ephy_window_get_active_tab (window);
+	embed = ephy_embed_container_get_active_child
+		(EPHY_EMBED_CONTAINER (window));
 
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
 	value = ephy_embed_event_get_property (event, "link");
 
-	ephy_shell_new_tab (ephy_shell, window, tab,
+	ephy_shell_new_tab (ephy_shell, window, embed,
 			    g_value_get_string (value),
 			    EPHY_NEW_TAB_OPEN_PAGE |
 			    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
@@ -204,7 +203,7 @@ save_property_url (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	value = ephy_embed_event_get_property (event, property);
@@ -239,7 +238,8 @@ popup_cmd_open_link (GtkAction *action,
 	const GValue *value;
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	event = ephy_window_get_context_event (window);
@@ -275,7 +275,8 @@ popup_cmd_save_image_as (GtkAction *action,
 #define GNOME_APPEARANCE_PROPERTIES  "gnome-appearance-properties.desktop"
 
 static void
-background_download_completed (EphyEmbedPersist *persist)
+background_download_completed (EphyEmbedPersist *persist,
+			       GtkWidget *window)
 {
 	const char *bg;
 	guint32 user_time;
@@ -285,15 +286,15 @@ background_download_completed (EphyEmbedPersist *persist)
 	bg = ephy_embed_persist_get_dest (persist);
 
 	/* open the Appearance Properties capplet on the Background tab */
-	if (!ephy_file_launch_desktop_file (GNOME_APPEARANCE_PROPERTIES, bg, user_time))
+	if (!ephy_file_launch_desktop_file (GNOME_APPEARANCE_PROPERTIES, bg, user_time, window))
 	{
 		/* Fallback for <= 2.18 desktop: try to open the "Background Properties" capplet */
-		if (!ephy_file_launch_desktop_file ("background.desktop", bg, user_time))
+		if (!ephy_file_launch_desktop_file ("background.desktop", bg, user_time, window))
 		{
 			/* If the above try didn't work, then we try the Fedora name.
 			 * This is a fix for #387206, but is actually a workaround for
 			 * bugzilla.redhat.com #201867 */
-			ephy_file_launch_desktop_file ("gnome-background.desktop", bg, user_time);
+			ephy_file_launch_desktop_file ("gnome-background.desktop", bg, user_time, window);
 		}
 	}
 
@@ -314,7 +315,7 @@ popup_cmd_set_image_as_background (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	value = ephy_embed_event_get_property (event, "image");
@@ -334,7 +335,7 @@ popup_cmd_set_image_as_background (GtkAction *action,
 
 	g_signal_connect (persist, "completed",
 			  G_CALLBACK (background_download_completed),
-			  NULL);
+			  window);
 
 	ephy_embed_persist_save (persist);
 
@@ -364,7 +365,8 @@ popup_cmd_open_frame (GtkAction *action,
 	char *location;
 	EphyEmbed *embed;
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	location = ephy_embed_get_location (embed, FALSE);
@@ -378,13 +380,13 @@ popup_cmd_open_frame (GtkAction *action,
  * doesn't work, fallback to open the URI in a new browser window.
  */
 static void
-image_open_uri (const char *remote_address,
-                const char *local_address,
+image_open_uri (GFile *file,
+                const char *remote_address,
 		guint32 user_time)
 {
 	gboolean success;
 
-	success = ephy_file_launch_handler (NULL, local_address, user_time);
+	success = ephy_file_launch_handler (NULL, file, user_time);
 
 	if (!success)
 	{
@@ -393,12 +395,12 @@ image_open_uri (const char *remote_address,
 				    EPHY_NEW_TAB_IN_NEW_WINDOW);
 	}
 
-	if (strcmp (remote_address, local_address) != 0)
+	if (strcmp (remote_address, g_file_get_uri (file)) != 0)
 	{
 		if (success)
-			ephy_file_delete_on_exit (local_address);
+			ephy_file_delete_on_exit (file);
 		else
-			gnome_vfs_unlink (local_address);
+			g_file_delete (file, NULL, NULL);
 	}
 }
 
@@ -408,13 +410,17 @@ save_source_completed_cb (EphyEmbedPersist *persist)
 	const char *dest;
 	const char *source;
 	guint32 user_time;
+	GFile *file;
 
 	user_time = ephy_embed_persist_get_user_time (persist);
 	dest = ephy_embed_persist_get_dest (persist);
 	source = ephy_embed_persist_get_source (persist);
 	g_return_if_fail (dest != NULL);
+	
+	file = g_file_new_for_path (dest);
 
-	image_open_uri (source, dest, user_time);
+	image_open_uri (file, source, user_time);
+	g_object_unref (file);
 }
 
 static void
@@ -468,19 +474,24 @@ popup_cmd_open_image (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	value = ephy_embed_event_get_property (event, "image");
 	address = g_value_get_string (value);
 
-	scheme = gnome_vfs_get_uri_scheme (address);
+	scheme = g_uri_get_scheme (address);
 	if (scheme == NULL) return;
 
 	if (strcmp (scheme, "file") == 0)
 	{
-		image_open_uri (address, address,
+		GFile *file;
+		
+		file = g_file_new_for_uri (address);
+		image_open_uri (file, address,
 				gtk_get_current_event_time ());
+		g_object_unref (file);
 	}
 	else
 	{
