@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: prefs-dialog.c 7695 2007-11-16 15:03:10Z xan $
+ *  $Id: prefs-dialog.c 7858 2008-01-13 20:42:01Z cosimoc $
  */
 
 #include "config.h"
@@ -41,6 +41,7 @@
 #include "ephy-file-helpers.h"
 #include "ephy-tree-model-node.h"
 #include "ephy-tree-model-sort.h"
+#include "pdm-dialog.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtklabel.h>
@@ -63,8 +64,6 @@
 #include <gtk/gtkmain.h>
 #include <string.h>
 
-#include <libgnomevfs/gnome-vfs-utils.h>
-
 #define CONF_FONTS_FOR_LANGUAGE	"/apps/epiphany/dialogs/preferences_font_language"
 #define DOWNLOAD_BUTTON_WIDTH	8
 
@@ -648,18 +647,15 @@ static void
 css_edit_button_clicked_cb (GtkWidget *button,
 			    PrefsDialog *pd)
 {
-	char *css_file, *uri;
+	GFile *css_file;
 
-	css_file = g_build_filename (ephy_dot_dir (),
-				     USER_STYLESHEET_FILENAME,
-				     NULL);
-	uri = gnome_vfs_get_uri_from_local_path (css_file);
+	css_file = g_file_new_for_path (g_build_filename (ephy_dot_dir (),
+							  USER_STYLESHEET_FILENAME,
+							  NULL));
 
-	ephy_file_launch_handler ("text/plain", uri,
+	ephy_file_launch_handler ("text/plain", css_file,
 				  gtk_get_current_event_time ());
-
-	g_free (css_file);
-	g_free (uri);
+	g_object_unref (css_file);
 }
 
 static void
@@ -1470,17 +1466,13 @@ static void
 prefs_clear_cache_button_clicked_cb (GtkWidget *button,
 				     PrefsDialog *dialog)
 {
-	EphyEmbedShell *shell;
-	EphyEmbedSingle *single;
-	EphyFaviconCache *cache;
+	GtkWidget *parent;
 
-	shell = ephy_embed_shell_get_default ();
-
-	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (shell));
-	ephy_embed_single_clear_cache (single);
-
-	cache = EPHY_FAVICON_CACHE (ephy_embed_shell_get_favicon_cache (shell));
-	ephy_favicon_cache_clear (cache);
+	parent = ephy_dialog_get_control (EPHY_DIALOG (dialog),
+					  properties[WINDOW_PROP].id);
+	pdm_dialog_show_clear_all_dialog (EPHY_DIALOG (dialog),
+					  parent,
+					  CLEAR_ALL_CACHE);
 }
 
 static void
